@@ -127,33 +127,29 @@ def sendeml(content, encoding="utf-8", host="127.0.0.1", port=25, ssl=False, use
 
 @click.group()
 def main():
-    """提供邮件发送相关函数及可执行程序。
+    """Sendmail client
 
+Notice:
 
-注意：
-
-
-1、如果可执行参数中没有提供邮件内容，则表示从STDIN中获取邮件内容。
-
-2、如果可执行参数中提供的邮件内容是一个文件，则读取文件内容作为邮件内容。
-
-3、其它情况则将可执行参数中提供的邮件内容作为邮件正文内容。
+1. Empty content means read mail content from stdin.
+2. If the content argument is a file path, read mail content from the file.
+3. Otherwise use the content argument as the mail content.
     """
     pass
 
 
 @main.command(name="makemail")
-@click.option("-f", "--from-address", required=True, help=u"发件人，如：姓名 <name@example.com>、name@example.com。")
-@click.option("-t", "--to-address", multiple=True, required=True, help=u"收件人，如：姓名 <name@example.com>、name@example.com。")
-@click.option("-s", "--subject", help=u"邮箱主题。")
-@click.option("-a", "--attach", multiple=True, required=False, help=u"邮件附件，可以使用多次。")
-@click.option("--html", is_flag=True, help=u"使用HTML格式。")
-@click.option("-e", "--encoding", default="utf-8", help=u"STDIN中邮件内容的字符编码，默认为UTF-8。")
-@click.option("-c", "--charset", default="utf-8", help=u"发送时邮件内容的编码，默认为UTF-8。")
-@click.option("-o", "--output", required=False, help=u"生成邮件的保存位置。")
+@click.option("-f", "--from-address", required=True, help=u"Mail sender, e.g. Name <name@example.com> or name@example.com.")
+@click.option("-t", "--to-address", multiple=True, required=True, help=u"Mail recipients, e.g. Name <name@example.com> or name@example.com.")
+@click.option("-s", "--subject", help=u"Mail subject")
+@click.option("-a", "--attach", multiple=True, required=False, help=u"Mail attachments, allow multiple use.")
+@click.option("--html", is_flag=True, help=u"Mail content is HTML format.")
+@click.option("-e", "--encoding", default="utf-8", help=u"Encoding of the mail content input.")
+@click.option("-c", "--charset", default="utf-8", help=u"Encoding of the mail content output.")
+@click.option("-o", "--output", required=False, help=u"Save the .eml file to the given path.")
 @click.argument("content", nargs=1, required=False)
 def makemail_cmd(from_address, to_address, subject, attach, html, encoding, charset, output, content):
-    """生成EML格式邮件。
+    """Make .eml file.
     """
     ignore_default_codec_map()
     to_addresses = to_address
@@ -161,21 +157,21 @@ def makemail_cmd(from_address, to_address, subject, attach, html, encoding, char
 
 
 @main.command(name="sendmail")
-@click.option("-f", "--from-address", required=True, help=u"发件人，如：姓名 <name@example.com>、name@example.com。")
-@click.option("-t", "--to-address", multiple=True, required=True, help=u"收件人，如：姓名 <name@example.com>、name@example.com。")
-@click.option("-s", "--subject", help=u"邮箱主题。")
-@click.option("-a", "--attach", multiple=True, required=False, help=u"邮件附件，可以使用多次。")
-@click.option("--html", is_flag=True, help=u"使用HTML格式。")
-@click.option("-e", "--encoding", default="utf-8", help=u"STDIN中邮件内容的字符编码，默认为UTF-8。")
-@click.option("-c", "--charset", default="utf-8", help=u"发送时邮件内容的编码，默认为UTF-8。")
-@click.option("-h", "--host", default="127.0.0.1", help=u"邮箱代理服务器地址，默认为127.0.0.1。")
-@click.option("-p", "--port", default=25, help=u"邮箱代理服务器端口，默认为25。")
-@click.option("--ssl", is_flag=True, help=u"邮箱代理服务器要求使用ssl加密链接。")
-@click.option("-u", "--user", help=u"邮箱代理服务器帐号，不提供则表示无需帐号认证。")
-@click.option("-P", "--password", help=u"邮箱代理服务器密码，不提供则表示无需帐号认证。")
+@click.option("-f", "--from-address", required=True, help=u"Mail sender, e.g. Name <name@example.com> or name@example.com.")
+@click.option("-t", "--to-address", multiple=True, required=True, help=u"Mail recipients, e.g. Name <name@example.com> or name@example.com.")
+@click.option("-s", "--subject", help=u"Mail subject")
+@click.option("-a", "--attach", multiple=True, required=False, help=u"Mail attachments, allow multiple use.")
+@click.option("--html", is_flag=True, help=u"Mail content is HTML format.")
+@click.option("-e", "--encoding", default="utf-8", help=u"Encoding of the mail content input.")
+@click.option("-c", "--charset", default="utf-8", help=u"Encoding of the mail content output.")
+@click.option("-h", "--host", default="127.0.0.1", help=u"Mail server address, default to 127.0.0.1.")
+@click.option("-p", "--port", default=25, help=u"Mail server port, default to 25. If you are using an ssl server, mostly the port should be 465.")
+@click.option("--ssl", is_flag=True, help=u"Mail server using ssl encryption.")
+@click.option("-u", "--user", help=u"Mail server login account. Empty user means don't use login.")
+@click.option("-P", "--password", help=u"Mail server login password. Empty password means don't use login.")
 @click.argument("content", nargs=1, required=False)
 def sendmail_cmd(from_address, to_address, subject, attach, html, encoding, charset, host, port, ssl, user, password, content):
-    u"""通过代理服务器发送邮件。
+    u"""Send mail
     """
     ignore_default_codec_map()
     to_addresses = to_address
@@ -183,15 +179,15 @@ def sendmail_cmd(from_address, to_address, subject, attach, html, encoding, char
 
 
 @main.command(name="sendeml")
-@click.option("-h", "--host", default="127.0.0.1", help=u"邮箱代理服务器地址，默认为127.0.0.1。")
-@click.option("-p", "--port", default=25, help=u"邮箱代理服务器端口，默认为25。")
-@click.option("--ssl", is_flag=True, help=u"邮箱代理服务器要求使用ssl加密链接。")
-@click.option("-u", "--user", help=u"邮箱代理服务器帐号，不提供则表示无需帐号认证。")
-@click.option("-P", "--password", help=u"邮箱代理服务器密码，不提供则表示无需帐号认证。")
-@click.option("-e", "--encoding", default="utf-8", help=u"STDIN中邮件内容的字符编码，默认为UTF-8。")
+@click.option("-h", "--host", default="127.0.0.1", help=u"Mail server address, default to 127.0.0.1.")
+@click.option("-p", "--port", default=25, help=u"Mail server port, default to 25. If you are using an ssl server, mostly the port should be 465.")
+@click.option("--ssl", is_flag=True, help=u"Mail server using ssl encryption.")
+@click.option("-u", "--user", help=u"Mail server login account. Empty user means don't use login.")
+@click.option("-P", "--password", help=u"Mail server login password. Empty password means don't use login.")
+@click.option("-e", "--encoding", default="utf-8", help=u"EML file encoding.")
 @click.argument("content", nargs=1, required=False)
 def sendeml_cmd(host, port, ssl, user, password, encoding, content):
-    u"""通过代理服务器发送EML格式邮件。
+    u"""Send eml file.
     """
     sendeml(content, encoding, host, port, ssl, user, password)
 
